
/**
 * Die Klasse reprsentiert eine Gerade mit Steigung und y-Achsenabschnitt
 * 
 * @author Garmann
 * @version 06.09.2007
 */
public class Gerade
{
    // instance variables - replace the example below with your own
    private double m; // Steigung
    private double b; // y-Achsenabschnitt

    /**
     * Konstruktor ohne Angabe von Parametern
     */
    public Gerade()
    {
        // initialise instance variables
        m = 0;
        b = 0;
    }

    /**
     * Konstruktor mit Angabe von Steigung und y-Achsenabschnitt
     * 
     * @param m: Steigung
     * @param b: y-Achsenabschnitt
     */
    public Gerade(double m, double b)
    {
        // initialise instance variables
        this.m = m;
        this.b = b;
    }

    /**
     * Konstruktor mit Angabe zweier Punkte
     * 
     * @param x1: x-Koordinate 1. Punkt
     * @param y1: y-Koordinate 1. Punkt
     * @param x2: x-Koordinate 2. Punkt
     * @param y2: y-Koordinate 2. Punkt
     */
    public Gerade(double x1, double y1, double x2, double y2)
    {
        // initialise instance variables
        this.m = (y2-y1)/(x2-x1);
        this.b = y2-m*x2;
    }

    /**
     * Konstruktor mit Angabe zweier Punkte
     * 
     * @param x1: x-Koordinate 1. Punkt
     * @param y1: y-Koordinate 1. Punkt
     * @param m: Steigung
     */
    public Gerade(double x1, double y1, double m)
    {
        // initialise instance variables
        this.m = m;
        this.b = y1-m*x1;
    }
    

    /** Getter-Methode fr Steigung m
     * 
     * @return m: Steigung
     */
    public double steigung()
    {
        return m;
    }

    /** Getter-Methode fr y-Achsenabschnitt b
     * 
     * @return b: yAbschnitt
     */
    public double yAbschnitt()
    {
        return b;
    }
    
    /** Berechnung der orthogonalen Steigung
     * 
     * @return o
     */
    public double orthogonaleSteigung()
    {
        return -1/m;
    }
    
    
    /** Berechnung der Nullstelle (x-Abschnitt)
     *  
     * @return xAbschnitt
     */
    public double xAbschnitt()
    {
        return -b/m;
    }

    /** Berechnung y-Wert zu x-Wert
     *  
     * @param x-Wert 
     * @return yWert
     */
    public double yWert(double x)
    {
        return m*x+b;
    }

    /** Berechnung x-Wert zu y-Wert
     *  
     * @param y-Wert 
     * @return xWert
     */
    public double xWert(double y)
    {
        return (y-b)/m;
    }
    
    
    /**
     * Bildschirmausgabe
     * 
     */
    public void ausgeben()
    {
        System.out.println("y = "+m+"*x + "+b);
    }
    
    /** Wertebabellen-Ausgabe
     * 
     * @param von: untere Grenze
     * @param bis: obere Grenze
     * @param schritt: Schrittweite
     */
    public void wertetabelleAusgeben(double von, double bis, double schritt)
    {
        System.out.print("Wertetabelle der Funktion ");
        ausgeben();
        System.out.println("-----------------------------------------------");
        System.out.println("\tx\t|\ty");
        System.out.println("--------------------------");
        for (double x=von; x<=bis; x+=schritt)
        {
            System.out.println("\t"+x+"\t|\t"+yWert(x));
        }
    }
    
    /** Schnittstellen-Berechnung
     * 
     * @param gerade
     * @return x-Wert
     */
    public double schnittstelle(Gerade g)
    {
        double x = (g.yAbschnitt()-this.yAbschnitt())/(this.steigung()-g.steigung());
        return x;
    }
 
    /** Paralle zur Geraden durch Punkt p
     * 
     * @param x1: x-Koordinate des Punktes P
     * @param y1: y-Koordinate des Punktes P
     */
    public Gerade orthogonale(double x1, double y1)
    {
        Gerade g = new Gerade(x1,y1,orthogonaleSteigung());
        return g;
    }
    
    /** Lsungsmethode fr Abstand Punkt Gerade
     * 
     * @param x1, y1 : Punkt
     */
    public void abstandPunkt(double x1, double y1)
    {
        Gerade o = orthogonale(x1,y1);
        double x2 = schnittstelle(o);
        double y2 = yWert(x2);
        double distanz = Math.sqrt((x1-x2)*(x1-x2)+(y1-y2)*(y1-y2));
        System.out.println(distanz);
    }
    
}
